@@ -1,4 +1,4 @@
-# Copyright 2014 - 2018 Avram Lubkin, All Rights Reserved
+# Copyright 2014 - 2020 Avram Lubkin, All Rights Reserved
 
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -17,7 +17,13 @@ import warnings
 from pluginlib.exceptions import PluginWarning
 from pluginlib._objects import GroupDict, TypeDict, PluginDict
 from pluginlib._util import (allow_bare_decorator, ClassProperty, DictWithDotNotation,
-                             LOGGER, Result, Undefined)
+                             LOGGER, PY26, Result, Undefined)
+
+try:
+    from asyncio import iscoroutinefunction
+except ImportError:  # pragma: no cover
+    iscoroutinefunction = lambda func: False  # noqa: E731
+
 
 DEFAULT = '_default'
 UNDEFINED = Undefined()
@@ -32,8 +38,6 @@ try:
 except NameError:
     STR = str
 
-PY26 = sys.version_info[:2] < (2, 7)
-
 # pylint: disable=protected-access
 
 
@@ -104,6 +108,10 @@ def _check_methods(cls, subclass):  # pylint: disable=too-many-branches
         if result:
             return result
 
+        # If abstract is a coroutine method, child should be too
+        if iscoroutinefunction(methobj) and not iscoroutinefunction(submethobj):
+            return Result(False, 'Does not contain required coroutine method (%s)' % meth, 215)
+
     return Result(True, None, 0)
 
 
