@@ -1,4 +1,4 @@
-# Copyright 2014 - 2018 Avram Lubkin, All Rights Reserved
+# Copyright 2014 - 2020 Avram Lubkin, All Rights Reserved
 
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -19,8 +19,11 @@ import operator as _operator
 import sys
 
 
+PY26 = sys.version_info[:2] < (2, 7)
+
+
 # Setup logger
-if sys.version_info[:2] < (2, 7):  # pragma: no branch
+if PY26:  # pragma: no branch
 
     class NullHandler(logging.Handler):  # pragma: no cover
         """NullHandler for Python 2.6"""
