@@ -1,4 +1,4 @@
-# Copyright 2014 - 2018 Avram Lubkin, All Rights Reserved
+# Copyright 2014 - 2020 Avram Lubkin, All Rights Reserved
 
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -15,6 +15,7 @@ import warnings
 from pkg_resources import Distribution, EntryPoint, working_set
 
 import pluginlib._loader as loader
+from pluginlib._objects import OrderedDict
 from pluginlib import BlacklistEntry, PluginImportError, EntryPointWarning
 
 from tests import TestCase, OUTPUT, mock
@@ -394,16 +395,19 @@ class TestPluginLoader(TestCase):
 
             self.assertEqual(len(plugins1.parser), 2)
             self.assertTrue('xml' in plugins1.parser)
-            self.assertIsInstance(plugins1.parser.xml, dict)
+            self.assertIsInstance(plugins1.parser.xml, OrderedDict)
             self.assertTrue('json' in plugins1.parser)
-            self.assertIsInstance(plugins1.parser.json, dict)
-            self.assertEqual(sorted(plugins1.parser.json.keys()), ['1.0', '2.0'])
+            self.assertIsInstance(plugins1.parser.json, OrderedDict)
+            self.assertEqual(tuple(plugins1.parser.json.keys()), ('1.0', '2.0'))
 
             plugins2 = ploader.plugins_all
             self.assertEqual(mock_load_modules.call_count, 1)
 
             self.assertEqual(plugins1, plugins2)
 
+            # Test for example in docs
+            self.assertIs(tuple(plugins1.parser.json.values())[-1], plugins1.parser.json['2.0'])
+
     def test_blacklist(self):
         """Blacklist prevents listing plugin"""
 
